use clap::Parser;
use anyhow::Result;
use xcb::x;

/// Macro recording module for easymacros. Outputs are partially compatible with xmacro.
#[derive(Parser, Debug)]
#[clap(author, version, about, long_about = None)]
struct Args {
    /// The file to record the macro to. Defaults to writing to stdout.
    #[clap(value_parser, value_name = "output_file", value_hint = clap::ValueHint::FilePath)]
    output_file: Option<std::path::PathBuf>,
    /// Display to run the macro on. This uses the $DISPLAY environment variable by default.
    #[clap(short = 'D', long)]
    display: Option<String>,
    /// Max Delay in milliseconds for macro delays
    #[clap(short, long)]
    max_delay: Option<u64>,
    /// Allow delay capturing in recording output. If this flag is set, the program will ignore the max_delay.
    #[clap(short, long)]
    ignore_delay_capturing: bool,
}

pub fn main() -> Result<()> {
    let args = Args::parse();

    let (connection, screen_nr) = xcb::Connection::connect(args.display.as_deref())?;

    Ok(())
}

fn get_stop_key(connection: xcb::Connection, screen_nr: i32) -> Result<x::Keycode> {
    let setup = connection.get_setup();
    let screen = setup.roots().nth(screen_nr as usize).unwrap();

    let grab_cookie = connection.send_request(&x::GrabKeyboard {
        owner_events: true,                 // get all pointer events specified by the following mask
        grab_window: screen.root(),         // grab the root window
        time: x::CURRENT_TIME,
        pointer_mode: x::GrabMode::Async,   // process events as normal, do not require sync
        keyboard_mode: x::GrabMode::Async,
    });

    let grab_reply = connection.wait_for_reply(grab_cookie);
    assert!(grab_reply.status() == x::GrabStatus::Success, "GrabKeyboard did not succeed");

    todo!()
}
